.. _requirements:

Requirements
============

Axes requires a supported Django version and runs on Python versions 3.8 and above.

Refer to the project source code repository in
`GitHub <https://github.com/jazzband/django-axes/>`_ and see the
`pyproject.toml file <https://github.com/jazzband/django-axes/blob/master/pyproject.toml>`_ and
`Python package definition <https://github.com/jazzband/django-axes/blob/master/setup.py>`_
to check if your Django and Python version are supported.

The `GitHub Actions builds <https://github.com/jazzband/django-axes/actions>`_
test Axes compatibility with the Django master branch for future compatibility as well.
